@@ -12,9 +12,7 @@ using Events for synchronization and CapacityLimiter for concurrency control.
 import os
 from typing import Any
 
-from lionagi.ln.concurrency.primitives import CapacityLimiter
-from lionagi.ln.concurrency.primitives import Event as ConcurrencyEvent
-from lionagi.ln.concurrency.task import create_task_group
+from lionagi.ln import AlcallParams, CapacityLimiter, ConcurrencyEvent
 from lionagi.operations.node import Operation
 from lionagi.protocols.types import EventStatus, Graph
 from lionagi.session.branch import Branch
@@ -36,6 +34,7 @@ class DependencyAwareExecutor:
         max_concurrent: int = 5,
         verbose: bool = False,
         default_branch: Branch | None = None,
+        alcall_params: AlcallParams | None = None,
     ):
         """Initialize the executor.
 
@@ -52,12 +51,14 @@ class DependencyAwareExecutor:
         self.context = context or {}
         self.max_concurrent = max_concurrent
         self.verbose = verbose
+        self._alcall = alcall_params or AlcallParams()
         self._default_branch = default_branch
 
         # Track results and completion
         self.results = {}
         self.completion_events = {}  # operation_id -> Event
         self.operation_branches = {}  # operation_id -> Branch
+        self.skipped_operations = set()  # Track skipped operations
 
         # Initialize completion events for all operations
         # and check for already completed operations
@@ -76,6 +77,9 @@ class DependencyAwareExecutor:
         if not self.graph.is_acyclic():
             raise ValueError("Graph must be acyclic for flow execution")
 
+        # Validate edge conditions before execution
+        self._validate_edge_conditions()
+
         # Pre-allocate ALL branches upfront to avoid any locking during execution
         await self._preallocate_all_branches()
 
@@ -88,19 +92,32 @@ class DependencyAwareExecutor:
         )
         limiter = CapacityLimiter(capacity)
 
-        # Execute all operations using structured concurrency
-        async with create_task_group() as tg:
-            for node in self.graph.internal_nodes.values():
-                if isinstance(node, Operation):
-                    await tg.start_soon(self._execute_operation, node, limiter)
+        nodes = [
+            n
+            for n in self.graph.internal_nodes.values()
+            if isinstance(n, Operation)
+        ]
+        await self._alcall(nodes, self._execute_operation, limiter=limiter)
 
-        # Return results
-        return {
-            "completed_operations": list(self.results.keys()),
+        # Return results - only include actually completed operations
+        completed_ops = [
+            op_id
+            for op_id in self.results.keys()
+            if op_id not in self.skipped_operations
+        ]
+
+        result = {
+            "completed_operations": completed_ops,
             "operation_results": self.results,
             "final_context": self.context,
+            "skipped_operations": list(self.skipped_operations),
         }
 
+        # Validate results before returning
+        self._validate_execution_results(result)
+
+        return result
+
     async def _preallocate_all_branches(self):
         """Pre-allocate ALL branches including for context inheritance to eliminate runtime locking."""
         operations_needing_branches = []
@@ -193,6 +210,23 @@ class DependencyAwareExecutor:
             return
 
         try:
+            # Check if this operation should be skipped due to edge conditions
+            should_execute = await self._check_edge_conditions(operation)
+
+            if not should_execute:
+                # Mark as skipped
+                operation.execution.status = EventStatus.SKIPPED
+                self.skipped_operations.add(operation.id)
+
+                if self.verbose:
+                    print(
+                        f"Skipping operation due to edge conditions: {str(operation.id)[:8]}"
+                    )
+
+                # Signal completion so dependent operations can proceed
+                self.completion_events[operation.id].set()
+                return
+
             # Wait for dependencies
             await self._wait_for_dependencies(operation)
 
@@ -235,9 +269,56 @@ class DependencyAwareExecutor:
                 print(f"Operation {str(operation.id)[:8]} failed: {e}")
 
         finally:
-            # Signal completion regardless of success/failure
+            # Signal completion regardless of success/failure/skip
             self.completion_events[operation.id].set()
 
+    async def _check_edge_conditions(self, operation: Operation) -> bool:
+        """
+        Check if operation should execute based on edge conditions.
+
+        Returns True if at least one valid path exists to this operation,
+        or if there are no incoming edges (head nodes).
+        Returns False if all incoming edges have failed conditions.
+        """
+        # Get all incoming edges
+        incoming_edges = [
+            edge
+            for edge in self.graph.internal_edges.values()
+            if edge.tail == operation.id
+        ]
+
+        # If no incoming edges, this is a head node - always execute
+        if not incoming_edges:
+            return True
+
+        # Check each incoming edge
+        has_valid_path = False
+
+        for edge in incoming_edges:
+            # Wait for the head operation to complete first
+            if edge.head in self.completion_events:
+                await self.completion_events[edge.head].wait()
+
+            # Check if the head operation was skipped
+            if edge.head in self.skipped_operations:
+                continue  # This path is not valid
+
+            # Build context for edge condition evaluation
+            result_value = self.results.get(edge.head)
+            if result_value is not None and not isinstance(
+                result_value, (str, int, float, bool)
+            ):
+                result_value = to_dict(result_value, recursive=True)
+
+            ctx = {"result": result_value, "context": self.context}
+
+            # Use edge.check_condition() which handles None conditions
+            if await edge.check_condition(ctx):
+                has_valid_path = True
+                break  # At least one valid path found
+
+        return has_valid_path
+
     async def _wait_for_dependencies(self, operation: Operation):
         """Wait for all dependencies to complete."""
         # Special handling for aggregations
@@ -248,10 +329,14 @@ class DependencyAwareExecutor:
                     f"Aggregation {str(operation.id)[:8]} waiting for {len(sources)} sources"
                 )
 
-            # Wait for ALL sources
-            for source_id in sources:
-                if source_id in self.completion_events:
-                    await self.completion_events[source_id].wait()
+            # Wait for ALL sources (sources are now strings from builder.py)
+            for source_id_str in sources:
+                # Convert string back to IDType for lookup
+                # Check all operations to find matching ID
+                for op_id in self.completion_events.keys():
+                    if str(op_id) == source_id_str:
+                        await self.completion_events[op_id].wait()
+                        break
 
         # Regular dependency checking
         predecessors = self.graph.get_predecessors(operation)
@@ -262,32 +347,6 @@ class DependencyAwareExecutor:
                 )
             await self.completion_events[pred.id].wait()
 
-        # Check edge conditions
-        incoming_edges = [
-            edge
-            for edge in self.graph.internal_edges.values()
-            if edge.tail == operation.id
-        ]
-
-        for edge in incoming_edges:
-            # Wait for head to complete
-            if edge.head in self.completion_events:
-                await self.completion_events[edge.head].wait()
-
-            # Evaluate edge condition
-            if edge.condition is not None:
-                result_value = self.results.get(edge.head)
-                if result_value is not None and not isinstance(
-                    result_value, (str, int, float, bool)
-                ):
-                    result_value = to_dict(result_value, recursive=True)
-
-                ctx = {"result": result_value, "context": self.context}
-                if not await edge.condition.apply(ctx):
-                    raise ValueError(
-                        f"Edge condition not satisfied for {str(operation.id)[:8]}"
-                    )
-
     def _prepare_operation(self, operation: Operation):
         """Prepare operation with context and branch assignment."""
         # Update operation context with predecessors
@@ -295,13 +354,18 @@ class DependencyAwareExecutor:
         if predecessors:
             pred_context = {}
             for pred in predecessors:
+                # Skip if predecessor was skipped
+                if pred.id in self.skipped_operations:
+                    continue
+
                 if pred.id in self.results:
                     result = self.results[pred.id]
                     if result is not None and not isinstance(
                         result, (str, int, float, bool)
                     ):
                         result = to_dict(result, recursive=True)
-                    pred_context[f"{pred.id}_result"] = result
+                    # Use string representation of IDType for JSON serialization
+                    pred_context[f"{str(pred.id)}_result"] = result
 
             if "context" not in operation.parameters:
                 operation.parameters["context"] = pred_context
@@ -364,7 +428,12 @@ class DependencyAwareExecutor:
                     ):
                         branch._message_manager.pile.clear()
                         for msg in primary_branch._message_manager.pile:
-                            branch._message_manager.pile.append(msg.clone())
+                            if hasattr(msg, "clone"):
+                                branch._message_manager.pile.append(
+                                    msg.clone()
+                                )
+                            else:
+                                branch._message_manager.pile.append(msg)
 
                     # Clear the pending flag
                     branch.metadata["pending_context_inheritance"] = False
@@ -386,6 +455,49 @@ class DependencyAwareExecutor:
             return self._default_branch
         return self.session.default_branch
 
+    def _validate_edge_conditions(self):
+        """Validate that all edge conditions are properly configured."""
+        for edge in self.graph.internal_edges.values():
+            if edge.condition is not None:
+                # Ensure condition is an EdgeCondition instance
+                from lionagi.protocols.graph.edge import EdgeCondition
+
+                if not isinstance(edge.condition, EdgeCondition):
+                    raise TypeError(
+                        f"Edge {edge.id} has invalid condition type: {type(edge.condition)}. "
+                        "Must be EdgeCondition or None."
+                    )
+
+                # Ensure condition has apply method
+                if not hasattr(edge.condition, "apply"):
+                    raise AttributeError(
+                        f"Edge {edge.id} condition missing 'apply' method."
+                    )
+
+    def _validate_execution_results(self, results: dict[str, Any]):
+        """Validate execution results for consistency."""
+        completed = set(results.get("completed_operations", []))
+        skipped = set(results.get("skipped_operations", []))
+
+        # Check for operations in both lists
+        overlap = completed & skipped
+        if overlap:
+            raise RuntimeError(
+                f"Operations {overlap} appear in both completed and skipped lists! "
+                "This indicates a bug in edge condition handling."
+            )
+
+        # Verify skipped operations have proper status
+        for node in self.graph.internal_nodes.values():
+            if isinstance(node, Operation) and node.id in skipped:
+                if node.execution.status != EventStatus.SKIPPED:
+                    # Log warning but don't fail - status might not be perfectly synced
+                    if self.verbose:
+                        print(
+                            f"Warning: Skipped operation {node.id} has status "
+                            f"{node.execution.status} instead of SKIPPED"
+                        )
+
 
 async def flow(
     session: Session,
@@ -396,6 +508,7 @@ async def flow(
     parallel: bool = True,
     max_concurrent: int = None,
     verbose: bool = False,
+    alcall_params: AlcallParams | None = None,
 ) -> dict[str, Any]:
     """Execute a graph using structured concurrency primitives.
 
@@ -410,6 +523,7 @@ async def flow(
         parallel: Whether to execute independent operations in parallel
         max_concurrent: Max concurrent operations (1 if not parallel)
         verbose: Enable verbose logging
+        alcall_params: Parameters for async parallel call execution
 
     Returns:
         Execution results with completed operations and final context
@@ -417,8 +531,7 @@ async def flow(
 
     # Handle concurrency limits
     if not parallel:
-        max_concurrent = 1  # Force sequential execution
-    # If max_concurrent is None, it means no limit
+        max_concurrent = 1
 
     # Execute using the dependency-aware executor
     executor = DependencyAwareExecutor(
@@ -428,6 +541,7 @@ async def flow(
         max_concurrent=max_concurrent,
         verbose=verbose,
         default_branch=branch,
+        alcall_params=alcall_params,
     )
 
     return await executor.execute()
