@@ -12,12 +12,14 @@ from pydantic import BaseModel
 from lionagi.libs.schema.as_readable import as_readable
 from lionagi.service.connections.endpoint import Endpoint
 from lionagi.service.connections.endpoint_config import EndpointConfig
-from lionagi.utils import is_import_installed, to_dict, to_list
+from lionagi.utils import to_dict, to_list
 
-from ._claude_code.models import (
+from ...third_party.claude_code import (
     CLAUDE_CODE_OPTION_PARAMS,
+    HAS_CLAUDE_CODE_SDK,
     ClaudeCodeRequest,
     ClaudePermission,
+    stream_cc_sdk_events,
 )
 
 __all__ = (
@@ -27,24 +29,27 @@ __all__ = (
     "ClaudeCodeEndpoint",
 )
 
-HAS_CLAUDE_CODE_SDK = is_import_installed("claude_code_sdk")
 
 # --------------------------------------------------------------------------- SDK endpoint
-ENDPOINT_CONFIG = EndpointConfig(
+
+_get_config = lambda: EndpointConfig(
     name="claude_code",
     provider="claude_code",
     base_url="internal",
     endpoint="query",
-    api_key="dummy",
     request_options=ClaudeCodeRequest,
     timeout=3000,
+    api_key="dummy-key",
 )
 
 
+ENDPOINT_CONFIG = _get_config()  # backward compatibility
+
+
 class ClaudeCodeEndpoint(Endpoint):
     """Direct Python-SDK (non-CLI) endpoint - unchanged except for bug-fixes."""
 
-    def __init__(self, config: EndpointConfig = ENDPOINT_CONFIG, **kwargs):
+    def __init__(self, config: EndpointConfig = None, **kwargs):
         if not HAS_CLAUDE_CODE_SDK:
             raise ImportError(
                 "claude_code_sdk is not installed. "
@@ -56,6 +61,7 @@ class ClaudeCodeEndpoint(Endpoint):
             DeprecationWarning,
         )
 
+        config = config or _get_config()
         super().__init__(config=config, **kwargs)
 
     def create_payload(self, request: dict | BaseModel, **kwargs):
@@ -64,16 +70,9 @@ class ClaudeCodeEndpoint(Endpoint):
         req_obj = ClaudeCodeRequest.create(messages=messages, **req_dict)
         return {"request": req_obj}, {}
 
-    def _stream_claude_code(self, request: ClaudeCodeRequest):
-        from claude_code_sdk import query as sdk_query
-
-        return sdk_query(
-            prompt=request.prompt, options=request.as_claude_options()
-        )
-
     async def stream(self, request: dict | BaseModel, **kwargs):
         payload, _ = self.create_payload(request, **kwargs)
-        async for chunk in self._stream_claude_code(payload["request"]):
+        async for chunk in stream_cc_sdk_events(payload["request"]):
             yield chunk
 
     def _parse_claude_code_response(self, responses: list) -> dict:
@@ -204,9 +203,6 @@ class ClaudeCodeEndpoint(Endpoint):
 
                     responses.append(chunk)
 
-        # 3. Parse the responses into a clean format
-        return self._parse_claude_code_response(responses)
-
 
 def _display_message(chunk, theme):
     from claude_code_sdk import types as cc_types
